@@ -1,5 +1,5 @@
-from pyBN.learning.structure.constraint.fast_iamb import *
+from pyCausalFS.pyBN.learning.structure.constraint.fast_iamb import *
 from pyCausalFS.pyBN.learning.structure.constraint.grow_shrink import *
 from pyCausalFS.pyBN.learning.structure.constraint.iamb import *
 from pyCausalFS.pyBN.learning.structure.constraint.lambda_iamb import *
-from pyBN.learning.structure.constraint.path_condition import *
\ No newline at end of file
+from pyCausalFS.pyBN.learning.structure.constraint.path_condition import *
\ No newline at end of file
