@@ -1,2 +1,2 @@
 from pyCausalFS.pyBN.learning.structure.naive.naive_bayes import *
-from pyBN.learning.structure.naive.TAN import *
\ No newline at end of file
+from pyCausalFS.pyBN.learning.structure.naive.TAN import *
\ No newline at end of file
